% P43mudim1.m Noise and dimensionality-1
%
% COPYRIGHT:  Aprend Technology and Robert E. ALvarez, 2014. All rights reserved.
 
%% init vars
post_title = 'P43mudim1';
% modify this for your computer
dirname = ['L:\Projects\Blog\Posts\' post_title '\'];
addpath([dirname 'code']);
MakeBlogPostFileLists(post_title);


%% prep data with adipose or iodine as 3rd material
tube_voltage = 120; % kiloVolts  
[~,~,specdat] = XrayTubeSpectrumTasmip(tube_voltage,'number_spectrum','clipzeros');
     % clip even more zeros
specdat.specnum = specdat.specnum(10:end); % 10 was 'eyeballed' from data
specdat.egys = specdat.egys(10:end);
   % normalize clipped spectrum
specdat.specnum = specdat.specnum/trapz(specdat.egys,specdat.specnum);
   % get the mus for the body tissues that will be used as basis funcs
tissues = {'soft_tissue','bone_cortical','adipose'}; % names in database
mus_body_materials = MusFromMaterials(tissues,specdat.egys);
fracI = 0.01; % fraction iodine in contrast--rest is water
musI = fracI*xraymu('I',specdat.egys) + (1-fracI)*xraymu('H2O',specdat.egys);

%%  test additional covariance formulas
nbasis = 3;
nbins = 6;
specdat.idx_threshold = OptimNbinsThresholds(specdat,nbins);
specdat.mus = zeros(numel(specdat.egys),nbasis); % use zeros since 
  % using 0 thickness in PoissonLambda
CLinv = diag(PoissonLambda(zeros(1,nbasis),specdat)); % inverse of covariance of log
additional_materials = {'adipose','iodine'};
ncases = length(additional_materials);
v = zeros(ncases,4); % summary data
mus_add = [mus_body_materials(:,3) musI]; % adipose, iodine atten. coeff.
for kcase = 1:ncases
    specdat.mus = [mus_body_materials(:,1:2) mus_add(:,kcase)];
    M = mubarNbinNdim(specdat,zeros(1,nbasis));
    F = M'*CLinv*M;
    R = inv(F);
    M2 = M(:,1:(nbasis-1));
    F2 = M2'*CLinv*M2;
    R2 = inv(F2);
    q = F(1:(nbasis-1),nbasis);
    u = F(nbasis,nbasis) - q'*R2*q;
    u_calc = det(F)/det(F2);
    u_error = u - u_calc;
    z = R2*q;
    R_add = (z*z')/u;
    R_error = norm(R(1:(nbasis-1),1:(nbasis-1)) - (R2 + R_add))/...
        norm(R(1:(nbasis-1),1:(nbasis-1)));
    v(kcase,:) = [u,u_calc ,u_error,R_error];
    fprintf('kcase %d nbasis %d nbins %d u-error %g addtl-cov error %g\n', ...
        kcase,nbasis,nbins,u_error, R_error);
end

%% output results
fname = [dirname 'AddtlCovParms.tex'];
s = matrix2latex(v,fname,'columnLabels',{'u','u calc','u error','frac-R error'}, ...
    'rowLabels',additional_materials,'format','%7.2e','alignment','c');

%% store code for later use
    if nbasis>2
        specdat.mus = [mus_body_materials(:,1:2) mus_add(:,kcase)];
    else
        specdat.mus = mus_body_materials(:,1:nbasis);
    end
